@@ -7,7 +7,7 @@ spectra <- Spectra(fls, backend = MsBackendMzR())
 
 ## build the results
 ## define the quality metrics to be calculated
-metrics <- c("chromatographyDuration", "ticQuartersRtFraction", 
+metrics <- c("chromatographyDuration", "ticQuantileRtFraction", 
     "ticQuartileToQuartileLogRatio", "numberSpectra", "areaUnderTic", 
     "msSignal10xChange")
 
@@ -43,9 +43,9 @@ suppressWarnings(
         msLevel = 1, relativeTo = "Q1", mode = "TIC", change = "jump"))
 
 ## START unit test calculateMetricsFromOneSampleSpectra ## 
-colnames_metrics <- c("chromatographyDuration", "ticQuartersRtFraction.0%",                  
-    "ticQuartersRtFraction.25%", "ticQuartersRtFraction.50%",
-    "ticQuartersRtFraction.75%", "ticQuartersRtFraction.100%",
+colnames_metrics <- c("chromatographyDuration", "ticQuantileRtFraction.0%",                  
+    "ticQuantileRtFraction.25%", "ticQuantileRtFraction.50%",
+    "ticQuantileRtFraction.75%", "ticQuantileRtFraction.100%",
     "ticQuartileToQuartileLogRatio.Q2/Q1",
     "ticQuartileToQuartileLogRatio.Q3/Q1",
     "ticQuartileToQuartileLogRatio.Q4/Q1",
@@ -175,9 +175,9 @@ test_that("calculateMetricsFromOneSampleSpectra", {
     expect_equal(attr(metrics_spectra_1, "chromatographyDuration"), "MS:4000053")
     expect_equal(attr(metrics_spectra_1_filtered, "chromatographyDuration"), 
         "MS:4000053")
-    expect_equal(attr(metrics_spectra_1, "ticQuartersRtFraction"), "MS:4000054")
-    expect_equal(attr(metrics_spectra_1_filtered, "ticQuartersRtFraction"), 
-        "MS:4000054")
+    expect_equal(attr(metrics_spectra_1, "ticQuantileRtFraction"), "MS:4000183")
+    expect_equal(attr(metrics_spectra_1_filtered, "ticQuantileRtFraction"), 
+        "MS:4000183")
     expect_equal(attr(metrics_spectra_1, "numberSpectra"), "MS:4000059")
     expect_equal(attr(metrics_spectra_1_filtered, "numberSpectra"), 
         "MS:4000059")
@@ -203,10 +203,10 @@ test_that("calculateMetricsFromOneSampleSpectra", {
         "MS:4000053")
     expect_equal(attr(metrics_spectra_2_filtered, "chromatographyDuration"), 
         "MS:4000053")
-    expect_equal(attr(metrics_spectra_2, "ticQuartersRtFraction"), 
-        "MS:4000054")
-    expect_equal(attr(metrics_spectra_2_filtered, "ticQuartersRtFraction"), 
-        "MS:4000054")
+    expect_equal(attr(metrics_spectra_2, "ticQuantileRtFraction"), 
+        "MS:4000183")
+    expect_equal(attr(metrics_spectra_2_filtered, "ticQuantileRtFraction"), 
+        "MS:4000183")
     expect_equal(attr(metrics_spectra_2, "numberSpectra"), 
         "MS:4000059")
     expect_equal(attr(metrics_spectra_2_filtered, "numberSpectra"), 
@@ -292,9 +292,9 @@ test_that("calculateMetricsFromSpectra", {
     expect_equal(attr(metrics_spectra, "chromatographyDuration"), "MS:4000053")
     expect_equal(attr(metrics_spectra_filtered, "chromatographyDuration"), 
         "MS:4000053")
-    expect_equal(attr(metrics_spectra, "ticQuartersRtFraction"), "MS:4000054")
-    expect_equal(attr(metrics_spectra_filtered, "ticQuartersRtFraction"), 
-        "MS:4000054")
+    expect_equal(attr(metrics_spectra, "ticQuantileRtFraction"), "MS:4000183")
+    expect_equal(attr(metrics_spectra_filtered, "ticQuantileRtFraction"), 
+        "MS:4000183")
     expect_equal(attr(metrics_spectra, "numberSpectra"), "MS:4000059")
     expect_equal(attr(metrics_spectra_filtered, "numberSpectra"), "MS:4000059")
     expect_equal(attr(metrics_spectra, "areaUnderTic"), "MS:4000155")
@@ -389,9 +389,9 @@ test_that("calculateMetricsFromMsExperiment", {
     expect_equal(attr(metrics_msexp, "chromatographyDuration"), "MS:4000053")
     expect_equal(attr(metrics_msexp_filtered, "chromatographyDuration"), 
                  "MS:4000053")
-    expect_equal(attr(metrics_msexp, "ticQuartersRtFraction"), "MS:4000054")
-    expect_equal(attr(metrics_msexp_filtered, "ticQuartersRtFraction"), 
-                 "MS:4000054")
+    expect_equal(attr(metrics_msexp, "ticQuantileRtFraction"), "MS:4000183")
+    expect_equal(attr(metrics_msexp_filtered, "ticQuantileRtFraction"), 
+                 "MS:4000183")
     expect_equal(attr(metrics_msexp, "numberSpectra"), "MS:4000059")
     expect_equal(attr(metrics_msexp_filtered, "numberSpectra"), "MS:4000059")
     expect_equal(attr(metrics_msexp, "areaUnderTic"), "MS:4000155")
@@ -543,14 +543,14 @@ test_that("calculateMetrics", {
         "MS:4000053")
     expect_equal(attr(metrics_msexp_wrapper_filtered, "chromatographyDuration"), 
         "MS:4000053")
-    expect_equal(attr(metrics_spectra_wrapper, "ticQuartersRtFraction"),
-        "MS:4000054")
-    expect_equal(attr(metrics_spectra_wrapper_filtered, "ticQuartersRtFraction"), 
-        "MS:4000054")
-    expect_equal(attr(metrics_msexp_wrapper, "ticQuartersRtFraction"),
-        "MS:4000054")
-    expect_equal(attr(metrics_msexp_wrapper_filtered, "ticQuartersRtFraction"), 
-        "MS:4000054")
+    expect_equal(attr(metrics_spectra_wrapper, "ticQuantileRtFraction"),
+        "MS:4000183")
+    expect_equal(attr(metrics_spectra_wrapper_filtered, "ticQuantileRtFraction"), 
+        "MS:4000183")
+    expect_equal(attr(metrics_msexp_wrapper, "ticQuantileRtFraction"),
+        "MS:4000183")
+    expect_equal(attr(metrics_msexp_wrapper_filtered, "ticQuantileRtFraction"), 
+        "MS:4000183")
     expect_equal(attr(metrics_spectra_wrapper, "numberSpectra"), 
         "MS:4000059")
     expect_equal(attr(metrics_spectra_wrapper_filtered, "numberSpectra"), 
@@ -601,13 +601,14 @@ test_that("calculateMetrics", {
 ## calculate the metrics from Spectra
 dO <- unique(spectra$dataOrigin)
 spectra_1 <- spectra[spectra$dataOrigin == dO[1], ]
-suppressWarnings(metrics_spectra_1 <- calculateMetricsFromOneSampleSpectra(
-    spectra = spectra_1, metrics = metrics, filterEmptySpectra = FALSE, 
-    msLevel = 1, relativeTo = "Q1", mode = "TIC", change = "jump", 
-    format = "mzQC"))
 
 ## START unit test calculateMetricsFromOneSampleSpectra ## 
 test_that("calculateMetricsFromOneSampleSpectra, format = 'mzQC'.", {
+    
+    metrics_spectra_1 <- calculateMetricsFromOneSampleSpectra(
+        spectra = spectra_1, metrics = metrics, filterEmptySpectra = FALSE, 
+        msLevel = 1, relativeTo = "Q1", mode = "TIC", change = "jump", 
+        format = "mzQC")
     ## spectra_1
     expect_equal(length(metrics_spectra_1), 12)
     expect_is(metrics_spectra_1, "numeric")
@@ -617,12 +618,12 @@ test_that("calculateMetricsFromOneSampleSpectra, format = 'mzQC'.", {
 
 ## START unit test calculateMetricsFromSpectra ##
 ## calculate the metrics from Spectra
-suppressWarnings(
-    metrics_spectra <- calculateMetricsFromSpectra(spectra = spectra,
-        metrics = metrics, filterEmptySpectra = FALSE, msLevel = 1, 
-        relativeTo = "Q1", mode = "TIC", change = "jump", format = "mzQC"))
-
 test_that("calculateMetricsFromSpectra, format = 'mzQC'.", {
+   
+   metrics_spectra <- calculateMetricsFromSpectra(spectra = spectra,
+            metrics = metrics, filterEmptySpectra = FALSE, msLevel = 1, 
+            relativeTo = "Q1", mode = "TIC", change = "jump", format = "mzQC")
+    
     expect_equal(length(metrics_spectra), 2)
     expect_equal(is(metrics_spectra[[1]]), c("MzQCmzQC", "envRefClass", 
         ".environment", "refClass", "environment", "refObject"))
@@ -687,16 +688,16 @@ test_that("calculateMetricsFromSpectra, format = 'mzQC'.", {
         metrics_spectra[[2]]$runQualities[[1]]$qualityMetrics[[1]]$unit, 
         list())
     
-    ## ticQuartersRtFraction
+    ## ticQuantileRtFraction
     expect_equal(
         metrics_spectra[[1]]$runQualities[[1]]$qualityMetrics[[2]]$accession, 
-        "MS:4000054")
+        "MS:4000183")
     expect_equal(
         metrics_spectra[[1]]$runQualities[[1]]$qualityMetrics[[2]]$name, 
-        "TIC quarters RT fraction")
+        "TIC quantile RT fraction")
     expect_equal(
         metrics_spectra[[1]]$runQualities[[1]]$qualityMetrics[[2]]$description, 
-        "\"The interval when the respective quarter of the TIC accumulates divided by retention time duration.\" [PSI:MS]")
+        "\"The interval when the respective quantile of the TIC accumulates divided by retention time duration. The number of values in the tuple implies the quantile mode.\" [PSI:MS]")
     expect_equal(
         metrics_spectra[[1]]$runQualities[[1]]$qualityMetrics[[2]]$value, 
         0, tolerance = 1e-06)
@@ -705,13 +706,13 @@ test_that("calculateMetricsFromSpectra, format = 'mzQC'.", {
         list())
     expect_equal(
         metrics_spectra[[2]]$runQualities[[1]]$qualityMetrics[[2]]$accession, 
-        "MS:4000054")
+        "MS:4000183")
     expect_equal(
         metrics_spectra[[2]]$runQualities[[1]]$qualityMetrics[[2]]$name, 
-        "TIC quarters RT fraction")
+        "TIC quantile RT fraction")
     expect_equal(
         metrics_spectra[[2]]$runQualities[[1]]$qualityMetrics[[2]]$description, 
-        "\"The interval when the respective quarter of the TIC accumulates divided by retention time duration.\" [PSI:MS]")
+        "\"The interval when the respective quantile of the TIC accumulates divided by retention time duration. The number of values in the tuple implies the quantile mode.\" [PSI:MS]")
     expect_equal(
         metrics_spectra[[2]]$runQualities[[1]]$qualityMetrics[[2]]$value, 
         0, tolerance = 1e-06)
@@ -846,11 +847,11 @@ spectra(msexp) <- Spectra(fls, backend = MsBackendMzR())
 ## additional parameters passed to the quality metrics functions
 ## (msLevel is an argument of areaUnderTic and msSignal10xChange,
 ## relativeTo is an argument of msSignal10xChange) passed to ...
-suppressWarnings(metrics_msexp <- calculateMetricsFromMsExperiment(msexp = msexp, 
-    metrics = metrics, filterEmptySpectra = FALSE, msLevel = 1, 
-    relativeTo = "Q1", mode = "TIC", change = "jump", format = "mzQC"))
-
 test_that("calculateMetricsFromMsExperiment, format = 'mzQC'.", {
+    suppressWarnings(metrics_msexp <- calculateMetricsFromMsExperiment(msexp = msexp, 
+        metrics = metrics, filterEmptySpectra = FALSE, msLevel = 1, 
+        relativeTo = "Q1", mode = "TIC", change = "jump", format = "mzQC"))
+    
     expect_equal(length(metrics_msexp), 2)
     expect_equal(is(metrics_msexp[[1]]), c("MzQCmzQC", "envRefClass", 
         ".environment", "refClass", "environment", "refObject"))
@@ -916,16 +917,16 @@ test_that("calculateMetricsFromMsExperiment, format = 'mzQC'.", {
         metrics_msexp[[2]]$runQualities[[1]]$qualityMetrics[[1]]$unit, 
         list())
     
-    ## ticQuartersRtFraction
+    ## ticQuantileRtFraction
     expect_equal(
         metrics_msexp[[1]]$runQualities[[1]]$qualityMetrics[[2]]$accession, 
-        "MS:4000054")
+        "MS:4000183")
     expect_equal(
         metrics_msexp[[1]]$runQualities[[1]]$qualityMetrics[[2]]$name, 
-        "TIC quarters RT fraction")
+        "TIC quantile RT fraction")
     expect_equal(
         metrics_msexp[[1]]$runQualities[[1]]$qualityMetrics[[2]]$description, 
-        "\"The interval when the respective quarter of the TIC accumulates divided by retention time duration.\" [PSI:MS]")
+        "\"The interval when the respective quantile of the TIC accumulates divided by retention time duration. The number of values in the tuple implies the quantile mode.\" [PSI:MS]")
     expect_equal(
         metrics_msexp[[1]]$runQualities[[1]]$qualityMetrics[[2]]$value, 
         0, tolerance = 1e-06)
@@ -934,13 +935,13 @@ test_that("calculateMetricsFromMsExperiment, format = 'mzQC'.", {
         list())
     expect_equal(
         metrics_msexp[[2]]$runQualities[[1]]$qualityMetrics[[2]]$accession, 
-        "MS:4000054")
+        "MS:4000183")
     expect_equal(
         metrics_msexp[[2]]$runQualities[[1]]$qualityMetrics[[2]]$name, 
-        "TIC quarters RT fraction")
+        "TIC quantile RT fraction")
     expect_equal(
         metrics_msexp[[2]]$runQualities[[1]]$qualityMetrics[[2]]$description, 
-        "\"The interval when the respective quarter of the TIC accumulates divided by retention time duration.\" [PSI:MS]")
+        "\"The interval when the respective quantile of the TIC accumulates divided by retention time duration. The number of values in the tuple implies the quantile mode.\" [PSI:MS]")
     expect_equal(
         metrics_msexp[[2]]$runQualities[[1]]$qualityMetrics[[2]]$value, 
         0, tolerance = 1e-06)
@@ -1051,17 +1052,17 @@ test_that("calculateMetricsFromMsExperiment, format = 'mzQC'.", {
 
 ## START unit test calculateMetrics ##
 ## calculate the metrics by the wrapper function
-suppressWarnings(
-    metrics_spectra_wrapper <- calculateMetrics(object = spectra,
-        metrics = metrics, filterEmptySpectra = FALSE, msLevel = 1, 
-        relativeTo = "Q1", mode = "TIC", change = "jump", format = "mzQC"))
-suppressWarnings(
-    metrics_msexp_wrapper <- calculateMetrics(object = msexp,
-        metrics = metrics, filterEmptySpectra = FALSE, msLevel = 1, 
-        relativeTo = "Q1", mode = "TIC", change = "jump", format = "mzQC"))
-
 test_that("calculateMetrics, format = 'mzQC'.", {
     
+    suppressWarnings(
+        metrics_spectra_wrapper <- calculateMetrics(object = spectra,
+            metrics = metrics, filterEmptySpectra = FALSE, msLevel = 1, 
+            relativeTo = "Q1", mode = "TIC", change = "jump", format = "mzQC"))
+    suppressWarnings(
+        metrics_msexp_wrapper <- calculateMetrics(object = msexp,
+            metrics = metrics, filterEmptySpectra = FALSE, msLevel = 1, 
+            relativeTo = "Q1", mode = "TIC", change = "jump", format = "mzQC"))
+    
     ## metrics_spectra_wrapper
     expect_equal(length(metrics_spectra_wrapper), 2)
     expect_equal(is(metrics_spectra_wrapper[[1]]), c("MzQCmzQC", "envRefClass", 
@@ -1127,16 +1128,16 @@ test_that("calculateMetrics, format = 'mzQC'.", {
         metrics_spectra_wrapper[[2]]$runQualities[[1]]$qualityMetrics[[1]]$unit, 
         list())
     
-    ## ticQuartersRtFraction
+    ## ticQuantileRtFraction
     expect_equal(
         metrics_spectra_wrapper[[1]]$runQualities[[1]]$qualityMetrics[[2]]$accession, 
-        "MS:4000054")
+        "MS:4000183")
     expect_equal(
         metrics_spectra_wrapper[[1]]$runQualities[[1]]$qualityMetrics[[2]]$name, 
-        "TIC quarters RT fraction")
+        "TIC quantile RT fraction")
     expect_equal(
         metrics_spectra_wrapper[[1]]$runQualities[[1]]$qualityMetrics[[2]]$description, 
-        "\"The interval when the respective quarter of the TIC accumulates divided by retention time duration.\" [PSI:MS]")
+        "\"The interval when the respective quantile of the TIC accumulates divided by retention time duration. The number of values in the tuple implies the quantile mode.\" [PSI:MS]")
     expect_equal(
         metrics_spectra_wrapper[[1]]$runQualities[[1]]$qualityMetrics[[2]]$value, 
         0, tolerance = 1e-06)
@@ -1145,13 +1146,13 @@ test_that("calculateMetrics, format = 'mzQC'.", {
         list())
     expect_equal(
         metrics_spectra_wrapper[[2]]$runQualities[[1]]$qualityMetrics[[2]]$accession, 
-        "MS:4000054")
+        "MS:4000183")
     expect_equal(
         metrics_spectra_wrapper[[2]]$runQualities[[1]]$qualityMetrics[[2]]$name, 
-        "TIC quarters RT fraction")
+        "TIC quantile RT fraction")
     expect_equal(
         metrics_spectra_wrapper[[2]]$runQualities[[1]]$qualityMetrics[[2]]$description, 
-        "\"The interval when the respective quarter of the TIC accumulates divided by retention time duration.\" [PSI:MS]")
+        "\"The interval when the respective quantile of the TIC accumulates divided by retention time duration. The number of values in the tuple implies the quantile mode.\" [PSI:MS]")
     expect_equal(
         metrics_spectra_wrapper[[2]]$runQualities[[1]]$qualityMetrics[[2]]$value, 
         0, tolerance = 1e-06)
@@ -1324,16 +1325,16 @@ test_that("calculateMetrics, format = 'mzQC'.", {
         metrics_msexp_wrapper[[2]]$runQualities[[1]]$qualityMetrics[[1]]$unit, 
         list())
     
-    ## ticQuartersRtFraction
+    ## ticQuantileRtFraction
     expect_equal(
         metrics_msexp_wrapper[[1]]$runQualities[[1]]$qualityMetrics[[2]]$accession, 
-        "MS:4000054")
+        "MS:4000183")
     expect_equal(
         metrics_msexp_wrapper[[1]]$runQualities[[1]]$qualityMetrics[[2]]$name, 
-        "TIC quarters RT fraction")
+        "TIC quantile RT fraction")
     expect_equal(
         metrics_msexp_wrapper[[1]]$runQualities[[1]]$qualityMetrics[[2]]$description, 
-        "\"The interval when the respective quarter of the TIC accumulates divided by retention time duration.\" [PSI:MS]")
+        "\"The interval when the respective quantile of the TIC accumulates divided by retention time duration. The number of values in the tuple implies the quantile mode.\" [PSI:MS]")
     expect_equal(
         metrics_msexp_wrapper[[1]]$runQualities[[1]]$qualityMetrics[[2]]$value, 
         0, tolerance = 1e-06)
@@ -1342,13 +1343,13 @@ test_that("calculateMetrics, format = 'mzQC'.", {
         list())
     expect_equal(
         metrics_msexp_wrapper[[2]]$runQualities[[1]]$qualityMetrics[[2]]$accession, 
-        "MS:4000054")
+        "MS:4000183")
     expect_equal(
         metrics_msexp_wrapper[[2]]$runQualities[[1]]$qualityMetrics[[2]]$name, 
-        "TIC quarters RT fraction")
+        "TIC quantile RT fraction")
     expect_equal(
         metrics_msexp_wrapper[[2]]$runQualities[[1]]$qualityMetrics[[2]]$description, 
-        "\"The interval when the respective quarter of the TIC accumulates divided by retention time duration.\" [PSI:MS]")
+        "\"The interval when the respective quantile of the TIC accumulates divided by retention time duration. The number of values in the tuple implies the quantile mode.\" [PSI:MS]")
     expect_equal(
         metrics_msexp_wrapper[[2]]$runQualities[[1]]$qualityMetrics[[2]]$value, 
         0, tolerance = 1e-06)
